# financialmodelingprep-python
Wrapper for financialmodelingprep API V3

## Installation
'''pip install financialmodelingprep'''

## License

© 2021 Joseph Cottingham

This repository is licensed under the MIT license
See LICENSE for details.